@@ -193,12 +193,12 @@ class Insight_Definition:
                     if(query not in ((str)(col["id"]))):
                         col["id"] = query + "-" +col["id"]
                     columns.append(col)
-                #cols = self.get_columns(query_ids)
             else:
                 cols = self.get_columns(query_ids)
                 for col in cols:
                     columns.append(col)
 
+        print(columns)
         settings = {}
         for field in field_codes.keys():
             ids = []
@@ -234,6 +234,7 @@ class Insight_Definition:
         for key in values.keys():
             settings[key + "_id"] = values[key]
 
+        print(settings)
         body = {
             "id" : widget_id,
             "type": "widget",
